==> rheolef_5.92.orig.tar.gz: rheolef-5.92/nfem/tst/form_2D_D_rz_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

APP="P1 P2"
Cz="0 1"
C="0"

status=0
command="../bin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command 2>/dev/null

for app in $APP; do
 case $app in
 P1) P="1 r z";;
 P2) P="1 r z r2 rz z2";;
 esac
 for i in $C; do
  for j in $Cz; do
   for p in $P; do
    for q in $P; do
     command="./form_2D_D_rz_tst square -approx $app -u-monom $p -v-monom $q -u-component $i -v-component $j"
     echo "      $command"
     eval $command >/dev/null 2>/dev/null
     if test $? -ne 0; then status=1; echo "        => *NO*"; fi
    done
   done
  done
 done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command
exit $status

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/nfem/tst/form_2D_D_rz_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

APP="P1 P2"
Cz="0 1"
C="0"

status=0
command="../sbin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command 2>/dev/null

for app in $APP; do
 case $app in
 P1) P="1 r z";;
 P2) P="1 r z r2 rz z2";;
 esac
 for i in $C; do
  for j in $Cz; do
   for p in $P; do
    for q in $P; do
     command="./form_2D_D_rz_tst square -approx $app -u-monom $p -v-monom $q -u-component $i -v-component $j"
     echo "      $command"
     eval $command >/dev/null 2>/dev/null
     if test $? -ne 0; then status=1; echo "        => *NO*"; fi
    done
   done
  done
 done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command
exit $status
